@@ -1,5 +1,6 @@
 from ChordInstrument import ChordInstrument
 from SimpleChordInstrument import SimpleChordInstrument
 from BoogieWoogieRhythm import BoogieWoogieRhythm
+from Strings import Strings
 
-__all__ = ['ChordInstrument', 'SimpleChordInstrument', 'BoogieWoogieRhythm']
+__all__ = ['ChordInstrument', 'SimpleChordInstrument', 'BoogieWoogieRhythm', 'Strings']
