@@ -470,6 +470,10 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		i = combo_index_by_text(self.ui.key, o.key)
 		if i != -1:
 			self.ui.key.setCurrentIndex(i)
+		i = 0 
+		if hasattr(o, "movement"):
+			i = combo_index_by_text(self.ui.movement, str(o.movement))
+		self.ui.movement.setCurrentIndex(i)
 
 		i = 0
 		if hasattr(o, 'visualization'):
@@ -516,6 +520,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		o.driver = self.driver
 		o.SF2 = self.soundfont
 		o.frontend = str(self.ui.visualization.currentText())
+		o.movement = str(self.ui.movement.currentText())
 		if o.frontend == '':
 			o.frontend = None
 		if o.driver == 'default':
